<?php
/**
 * @author
 * Name: Sigrid Suski & Radek Suski, Sigsiu.NET GmbH
 * Email: www@joomla.net.pl
 * Url: http://joomla.net.pl
 * @copyright Copyright (C) 2006 - 2013 Sigsiu.NET GmbH (http://www.sigsiu.net). All rights reserved.
 * @license GNU/LGPL Version 3
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License version 3 as published by the Free Software Foundation, and under the additional terms according section 7 of GPL v3.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * $Author: Radek Suski $
 */
defined( '_JEXEC' ) or die;

class plgSystemJnpl_cookie extends JPlugin
{
	private $cookieId = 'something';
	/** @JInputCookie */
	private $input = null;
	private static $run = false;
	const CONTENT = 1;
	const GET_ID = 'cookieOn';
	private $content = null;

	public function __construct( &$subject, $config = array() )
	{
		parent::__construct( $subject, $config );
		$this->input = JFactory::getApplication()->input->cookie;
	}

	public function onAfterRoute()
	{
		$go = JFactory::getDocument()->getType() === 'html' && !( JFactory::getUser()->get( 'id' ) && $this->params->get( 'unregisteredOnly', false ) ) && JFactory::getApplication()->getName() == 'site';
		if ( !( $go ) ) {
			return true;
		}
		$this->cookieId = trim( preg_replace( '/[^a-zA-Z0-9]/', '-', $this->params->get( 'cookieId' ) ) );
		// if we got acceptance in POST
		if ( JFactory::getApplication()->input->post->get( self::GET_ID ) ) {
			$this->input->set( $this->cookieId, self::CONTENT, ( time() * 2 ), '/' );
		}
		// otherwise if we didn't get acceptance via cookie, remove all cookies in destructor
		// and show the message
		elseif ( !( $this->input->get( $this->cookieId, false, 'int' ) ) ) {
			self::$run = true;
			$this->content = $this->params->get( 'message' );
		}
		if ( self::$run ) {
			if ( $this->params->get( 'destroyCookies', true ) ) {
				JFactory::getDocument()
						->addScriptDeclaration( '
							var jnplOnready = function(handler) {
							    if(document && document.readyState==="complete") return handler();
							    if(window.addEventListener) window.addEventListener("DOMContentLoaded",handler,false);
							    else if(window.attachEvent && window==window.top) { if(_readyQueue.push(handler)==1) _readyIEtop(); }
							    else if(window.attachEvent) window.attachEvent("onload",handler);
							};
							var resetCookies = function () {
								 var cookies = document.cookie.split(";");
								 for (var i = 0; i < cookies.length; i++) {
								    document.cookie = cookies[i].split("=")[0] + "=;expires=Thu, 01 Jan 1970 00:00:00 GMT";
								 }
							 };
							 setTimeout( function() { jnplOnready( resetCookies ); }, 10 );
					     ' );
			}
			JFactory::getDocument()->addStyleDeclaration( $this->params->get( 'css' ) );
		}
	}

	public function onAfterRender()
	{
		if ( self::$run ) {
			$this->destroyCookies();
			$target = JUri::current();
			$target = explode( '#', $target );
			$target = $target[ 0 ];
			$this->content = str_replace( array( '{button}', '{/button}' ), array( '<form action="' . $target . '" method="post"><button type="submit" class="btn btn-mini">', '</button><input type="hidden" name="' . self::GET_ID . '" value="1"/></form>' ), $this->content );
			$output = JResponse::getBody();
			$output = preg_replace( '/(<body[^>]*>)/', '\1' . $this->content, $output );
			JResponse::setBody( $output );
		}
	}

	private function destroyCookies()
	{
		// remove all cookies first
		if ( $this->params->get( 'destroyCookies', true ) && count( $_COOKIE ) ) {
			foreach ( $_COOKIE as $ident => $content ) {
				$this->input->set( $ident, $content, 1 );
				unset( $_COOKIE[ $ident ] );
			}
		}
	}

	// last attempt
	public function __destruct()
	{
		if ( self::$run ) {
			$this->destroyCookies();
		}
	}
}
